Crate user_notify

Crate user_notify 

Show desktop notifications to end users on linux, macOS and windows.

If you want to see the platform implementation and view this on docs.rs, then make sure to select the correct platform in the header bar.

Modules

mock
This manager logs the calls to it and does nothing more. It can be used for testing application code, or as a fallback for tauri’s devmode that runs the app without a bundle id
xdg
Linux implementation

Structs

NotificationBuilder
A builder struct for building notifications.
NotificationCategory
Notification Categories are used to define actions for notifications that have this category set.
NotificationResponse
Emmited when user clicked on a notification

Enums

Error
user-notify error type
NotificationCategoryAction
An action to display in a notifications.
NotificationResponseAction
An action the user took to trigger the NotificationResponse
XdgNotificationCategory
Category for the notification

Traits

NotificationHandle
A Handle to a sent notification
NotificationManager
Manager for active notifications.

Functions

get_notification_manager
Get the notification manager for the platform