pub enum NotificationResponseAction {
Default,
Dismiss,
Other(String),
}Expand description
An action the user took to trigger the NotificationResponse
Variants
Default
When user clicks on the notification
Platform Specific
- MacOS: corresponds to UNNotificationDefaultActionIdentifier
Dismiss
When user closes the notification
Platform Specific
- MacOS: corresponds to UNNotificationDismissActionIdentifier
Other(String)
The identifier string of the action that the user selected, if it is not one of the other actions in NotificationResponseAction