XdgNotificationCategory

Enum XdgNotificationCategory 

pub enum XdgNotificationCategory {
Show 25 variants Call, CallEnded, CallIncoming, CallUnanswered, Device, DeviceAdded, DeviceError, DeviceRemoved, Email, EmailArrived, EmailBounced, Im, ImError, ImReceived, Network, NetworkConnected, NetworkDisconnected, NetworkError, Presence, PresenceOffline, PresenceOnline, Transfer, TransferComplete, TransferError, Custom(String),
}
Variants



Call

A generic audio or video call notification that doesn’t fit into any other category.



CallEnded

An audio or video call was ended.



CallIncoming

A audio or video call is incoming.



CallUnanswered

An incoming audio or video call was not answered.



Device

A generic device-related notification that doesn’t fit into any other category.



DeviceAdded

A device, such as a USB device, was added to the system.



DeviceError

A device had some kind of error.



DeviceRemoved

A device, such as a USB device, was removed from the system.



Email

A generic e-mail-related notification that doesn’t fit into any other category.



EmailArrived

A new e-mail notification.



EmailBounced

A notification stating that an e-mail has bounced.



Im

A generic instant message-related notification that doesn’t fit into any other category.



ImError

An instant message error notification.



ImReceived

A received instant message notification.



Network

A generic network notification that doesn’t fit into any other category.



NetworkConnected

A network connection notification, such as successful sign-on to a network service. This should not be confused with device.added for new network devices.



NetworkDisconnected

A network disconnected notification. This should not be confused with device.removed for disconnected network devices.



NetworkError

A network-related or connection-related error.



Presence

A generic presence change notification that doesn’t fit into any other category, such as going away or idle.



PresenceOffline

An offline presence change notification.



PresenceOnline

An online presence change notification.



Transfer

A generic file transfer or download notification that doesn’t fit into any other category.



TransferComplete

A file transfer or download complete notification.



TransferError

A file transfer or download error.



Custom(String)

Allows custom Category If it is not standard, then category should be in the form of “x-vendor.class.name.”