pub struct NotificationCategory {
pub identifier: String,
pub actions: Vec<NotificationCategoryAction>,
}Expand description
Notification Categories are used to define actions for notifications that have this category set.
Think of it like a template for notications. To store data for a notification, use NotificationBuilder::set_user_info and retrieve it via NotificationHandle::get_user_info or NotificationResponse::user_info.
Fields
identifier: StringId of the category by which it is referenced on notifications NotificationBuilder::set_category_id
actions: Vec<NotificationCategoryAction>The actions to display when the system delivers notifications of this type.