#[non_exhaustive]pub struct NotificationResponse {
pub notification_id: String,
pub action: NotificationResponseAction,
pub user_text: Option<String>,
pub user_info: HashMap<String, String>,
}Expand description
Emmited when user clicked on a notification
Platform-specific
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notification_id: Stringid of the notification that was assigned by the system
action: NotificationResponseActionThe action the user took to trigger the response
user_text: Option<String>The text that the user typed in as reponse
Platform Specific
- MacOS: corresponds to UNTextInputNotificationResponse.userText
- Linux: not supported
user_info: HashMap<String, String>Data stored inside of the notification