Show desktop notifications to end users on linux, macOS and windows.
If you want to see the platform implementation and view this on docs.rs, then make sure to select the correct platform in the header bar.
Modules
- mock
- This manager logs the calls to it and does nothing more. It can be used for testing application code, or as a fallback for tauri’s devmode that runs the app without a bundle id
- xdg
- Linux implementation
Structs
- Notification
Builder - A builder struct for building notifications.
- Notification
Category - Notification Categories are used to define actions for notifications that have this category set.
- Notification
Response - Emmited when user clicked on a notification
Enums
- Error
- user-notify error type
- Notification
Category Action - An action to display in a notifications.
- Notification
Response Action - An action the user took to trigger the NotificationResponse
- XdgNotification
Category - Category for the notification
Traits
- Notification
Handle - A Handle to a sent notification
- Notification
Manager - Manager for active notifications.
Functions
- get_
notification_ manager - Get the notification manager for the platform