pub struct NotificationBuilder { /* private fields */ }Expand description
A builder struct for building notifications.
Implementations
Sourceimpl NotificationBuilderwhere
Self: Sized,
impl NotificationBuilderwhere
Self: Sized,
Sourcepub fn body(self, body: &str) -> Self
pub fn body(self, body: &str) -> Self
Main content of notification
Plaform specific:
- MacOS: UNNotificationContent/body
- Linux / XDG: body
- Windows: text2
Sourcepub fn title(self, title: &str) -> Self
pub fn title(self, title: &str) -> Self
Primary description of notification
Plaform specific:
- MacOS: UNNotificationContent/title
- Linux / XDG: summary
- Windows: text2
Sourcepub fn subtitle(self, subtitle: &str) -> Self
pub fn subtitle(self, subtitle: &str) -> Self
Sets secondary description of Notification
Plaform specific:
- MacOS UNNotificationContent/subtitle
- Linux / XDG: not suported!
- Windows text1
Sourcepub fn set_image(self, path: PathBuf) -> Self
pub fn set_image(self, path: PathBuf) -> Self
Set Image Attachment
Plaform specific:
- MacOS: passed by file path, must be gif, jpg, or png
- For linux the file is read and transfered over dbus (in case you are in a flatpak and it can’t read from files) “image-data”
- Windows: passed by file path. image
Sourcepub fn set_icon(self, path: PathBuf) -> Self
pub fn set_icon(self, path: PathBuf) -> Self
Set App icon
Plaform specific:
- MacOS: not supported to change the app icon?
- For linux the file is read and transfered over dbus (in case you are in a flatpak and it can’t read from files) app_icon
- Windows:
<image placement="appLogoOverride" />
Sourcepub fn set_icon_round_crop(self, icon_round_crop: bool) -> Self
pub fn set_icon_round_crop(self, icon_round_crop: bool) -> Self
Set App icon to be round
Plaform specific:
- MacOS: not supported
- Linux: not supported
- Windows:
<image placement='appLogoOverride' hint-crop='circle' />
Sourcepub fn set_thread_id(self, thread_id: &str) -> Self
pub fn set_thread_id(self, thread_id: &str) -> Self
Set Thread id, this is used to group related notifications
Plaform specific:
- MacOS: UNNotificationContent/threadIdentifier
- Linux not specified yet:
- Windows: not supported
Sourcepub fn set_category_id(self, category_id: &str) -> Self
pub fn set_category_id(self, category_id: &str) -> Self
Set the notification Category, those are basically templates how the notification should be displayed
It is used to add a text field or buttons to the notification.
Categories are defined by passing them to NotificationManager::register on app startup
Sourcepub fn set_xdg_category(self, category: XdgNotificationCategory) -> Self
pub fn set_xdg_category(self, category: XdgNotificationCategory) -> Self
Set the xdg notification Category
The type of notification this is acording to https://specifications.freedesktop.org/notification-spec/latest/categories.html
Platform specific: only work on linux, this does nothing on other platforms
Sourcepub fn set_xdg_app_name(self, name: String) -> Self
pub fn set_xdg_app_name(self, name: String) -> Self
Set the xdg App Name
Platform specific: only work on linux, this does nothing on other platforms
Sourcepub fn set_user_info(self, user_info: HashMap<String, String>) -> Self
pub fn set_user_info(self, user_info: HashMap<String, String>) -> Self
Set metadata for a notification
Platform Specific
- on MacOS this uses UserInfo field in the notification content, so it works accross sessions
- windows stores this in toast NotificationData
- linux: on linux we emulate this by storing this info inside of NotificationManager